@@ -1,5 +1,5 @@
 #include <stdio.h>
-#include <MLV_all.h>
+#include <MLV/MLV_all.h>
 #include <math.h>
 
 //
@@ -767,7 +767,7 @@ int main( int argc, char *argv[] ){
 		"MLV_COLOR_LIGHT_GREEN",
 		"MLV_COLOR_LIGHTGREEN"
 	};
-	Uint32 couleur[NB_COULEUR] ={
+	MLV_Color couleur[NB_COULEUR] ={
 		MLV_COLOR_SNOW,
 		MLV_COLOR_GHOST_WHITE,
 		MLV_COLOR_GHOSTWHITE,
